use leptos::{logging, server, ServerFnError};

cfg_if::cfg_if! {
    if #[cfg(feature = "ssr")] {
        use once_cell::sync::Lazy;
        use surrealdb::engine::remote::ws::{Client, Ws};
        use surrealdb::opt::auth::Root;
        use surrealdb::Surreal;

        pub static DB: Lazy<Surreal<Client>> = Lazy::new(Surreal::init);

        pub mod schemas;
    }
}

#[cfg(feature = "ssr")]
pub async fn connect() -> Result<(), ServerFnError> {
    DB.connect::<Ws>("localhost:80").await?;

    DB.signin(Root {
        username: "root",
        password: "root",
    })
    .await?;

    DB.use_ns("wrb").use_db("timings").await?;

    Ok(())
}

#[server]
pub async fn add_participant(name: String, group: String) -> Result<(), ServerFnError> {
    let created: Vec<schemas::Participant> = DB
        .create("participant")
        .content(schemas::NewParticipant { name, group })
        .await?;

    match created.first() {
        Some(participant) => {
            logging::log!(
                "Succesfully created participant: {} ({})",
                participant.name,
                participant.group
            );
            Ok(())
        }
        None => Err(ServerFnError::ServerError(String::from(
            "Could not create participant",
        ))),
    }
}
